@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class AkonadiContactRepository : public QObject, public Domain::ContactRepositor
     Q_OBJECT
 public:
     AkonadiContactRepository();
-    ~AkonadiContactRepository();
+    ~AkonadiContactRepository() override;
 
     KJob *createContact(Domain::Contact *contact) override;
     KJob *removeContact(Domain::Contact *contact) override;
