@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class KAddressBookConfigPluginListWidget : public PimCommon::ConfigurePluginsLis
     Q_OBJECT
 public:
     explicit KAddressBookConfigPluginListWidget(QWidget *parent = nullptr);
-    ~KAddressBookConfigPluginListWidget();
+    ~KAddressBookConfigPluginListWidget() override;
 
     void save() override;
     void doLoadFromGlobalSettings() override;
