@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ class KADDRESSBOOKDOMAIN_EXPORT ContactGroupRepository
 {
 public:
     ContactGroupRepository();
-    virtual ~ContactGroupRepository();
+    ~ContactGroupRepository() override;
     virtual KJob *createContactGroup(Domain::ContactGroup *contactGroup) = 0;
     virtual KJob *removeContactGroup(Domain::ContactGroup *contactGroup) = 0;
     virtual KJob *updateContactGroup(Domain::ContactGroup *contactGroup) = 0;
